@@ -12,5 +12,6 @@ from .api import create_vydana_faktura, create_prijata_faktura, create_bank_dokl
 ,get_prijata_faktura, get_prijata_faktura_by_code, get_all_bank_doklady, get_bank_doklad\
 ,get_bank_doklad_by_code, get_adresar, get_adresar_by_code, get_template_dict, delete_adresar\
 ,delete_bank_doklad, delete_vydana_faktura, delete_prijata_faktura, update_vydana_faktura\
-,update_prijata_faktura, update_bank_doklad, get_faktura_vydana_pdf_url, get_faktura_prijata_pdf_url
+,update_prijata_faktura, update_bank_doklad, get_faktura_vydana_pdf_url, get_faktura_prijata_pdf_url\
+,proved_sparovani
 
