@@ -111,4 +111,7 @@ def get_faktura_prijata_pdf_url(id):
 	return invoice.get_faktura_prijata_pdf_url(id)
 
 def get_faktura_vydana_pdf_url(id):
-	return invoice.get_faktura_vydana_pdf_url(id)	
\ No newline at end of file
+	return invoice.get_faktura_vydana_pdf_url(id)	
+
+def proved_sparovani():
+	main.proved_sparovani_plateb()	
\ No newline at end of file
